package com.zhyc.module.biosafety.service;

import java.util.List;

import com.zhyc.module.biosafety.domain.QuarantineReport;

/**
 * 检疫记录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-14
 */
public interface IQuarantineReportService 
{
    /**
     * 查询检疫记录
     * 
     * @param id 检疫记录主键
     * @return 检疫记录
     */
    public QuarantineReport selectQuarantineReportById(Long id);

    /**
     * 查询检疫记录列表
     * 
     * @param quarantineReport 检疫记录
     * @return 检疫记录集合
     */
    public List<QuarantineReport> selectQuarantineReportList(QuarantineReport quarantineReport);

    /**
     * 新增检疫记录
     * 
     * @param quarantineReport 检疫记录
     * @return 结果
     */
    public int insertQuarantineReport(QuarantineReport quarantineReport);

    /**
     * 修改检疫记录
     * 
     * @param quarantineReport 检疫记录
     * @return 结果
     */
    public int updateQuarantineReport(QuarantineReport quarantineReport);

    /**
     * 批量删除检疫记录
     * 
     * @param ids 需要删除的检疫记录主键集合
     * @return 结果
     */
    public int deleteQuarantineReportByIds(Long[] ids);

    /**
     * 删除检疫记录信息
     * 
     * @param id 检疫记录主键
     * @return 结果
     */
    public int deleteQuarantineReportById(Long id);
}
